==> 0.0.44.tar.gz: lib/widget/custom/custom_background_image.dart <==
import 'package:flutter/material.dart';

import '../../common/values/sizes.dart';

class CustomBackgroundImage extends StatefulWidget {
  const CustomBackgroundImage(
      {Key? key,
      required this.child,
      this.isScoll = false,
      this.imageCustom,
      this.backgroundImage,
      this.backgroundColor})
      : super(key: key);
  final Widget child;
  final bool? isScoll;
  final Widget? imageCustom;
  final Widget? backgroundImage;
  final Color? backgroundColor;

  @override
  State<CustomBackgroundImage> createState() => _CustomBackgroundImageState();
}

class _CustomBackgroundImageState extends State<CustomBackgroundImage> {
  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        SizedBox(
            height: Sizes.HEIGHT_100,
            child: widget.backgroundImage ?? Container()),
        Container(
          color: widget.backgroundColor,
          child: widget.isScoll == true
              ? Stack(
                  children: [
                    widget.imageCustom ?? Container(),
                    FlexibleSpaceBar(
                        centerTitle: true,
                        titlePadding: const EdgeInsets.all(20),
                        background: widget.child),
                  ],
                )
              : Stack(
                  children: [
                    widget.imageCustom ?? Container(),
                    widget.child,
                  ],
                ),
        ),
      ],
    );
  }
}

==> 0.0.62.tar.gz: lib/widget/custom/custom_background_image.dart <==
import 'package:flutter/material.dart';

import '../../common/values/sizes.dart';

class CustomBackgroundImage extends StatefulWidget {
  const CustomBackgroundImage(
      {Key? key,
      required this.child,
      this.isScoll = false,
      this.imageCustom,
      this.backgroundImage,
      this.heightBar,
      this.backgroundColor})
      : super(key: key);
  final Widget child;
  final bool? isScoll;
  final Widget? imageCustom;
  final Widget? backgroundImage;
  final Color? backgroundColor;
  final double? heightBar;

  @override
  State<CustomBackgroundImage> createState() => _CustomBackgroundImageState();
}

class _CustomBackgroundImageState extends State<CustomBackgroundImage> {
  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        SizedBox(
            height: widget.heightBar ?? Sizes.HEIGHT_100,
            child: widget.backgroundImage ?? Container()),
        Container(
          color: widget.backgroundColor,
          child: widget.isScoll == true
              ? Stack(
                  children: [
                    widget.imageCustom ?? Container(),
                    FlexibleSpaceBar(
                        centerTitle: true,
                        titlePadding: const EdgeInsets.all(20),
                        background: widget.child),
                  ],
                )
              : Stack(
                  children: [
                    widget.imageCustom ?? Container(),
                    widget.child,
                  ],
                ),
        ),
      ],
    );
  }
}
